local BaikCore = LibStub("AceAddon-3.0"):GetAddon("BaikCore")
local BaikUnitFrame = BaikCore.BaikUnitFrame
local Database = BaikCore.Database
local Hook = BaikCore.Hook
local Log = BaikCore.Log
local Option = BaikCore.Option
local RootStatusBar = BaikCore.StatusBar

-- Add Module
local StatusBar = BaikUnitFrame:NewModule("StatusBar", "AceHook-3.0")

-- Constants
local UNIT_TEXTURE_DB = "unit_status_bar"

local function GetOpt()
    return RootStatusBar:GetOpts("StatusBar", UNIT_TEXTURE_DB)
end

local STATUSBARS = {
    -- Player
    PlayerFrameHealthBar,
    PlayerFrameManaBar,
    PlayerFrameAlternateManaBar,
    CastingBarFrame,
    -- Target
    TargetFrameHealthBar,
    TargetFrameManaBar,
    TargetFrameSpellBar,
    -- Focus
    FocusFrameHealthBar,
    FocusFrameManaBar,
    FocusFrameSpellBar,
}

-- Private Methods
local function PostHook_UnitFrameManaBar_UpdateType(manaBar, ...)
    RootStatusBar:SyncBar(manaBar, UNIT_TEXTURE_DB)
end

-- Ace3 Callbacks
function StatusBar:OnInitialize()
    Log:v("StatusBar_OnInitialize")
    Database:InitIfEmpty(UNIT_TEXTURE_DB, RootStatusBar.DEFAULT)
    Option:AddOption(BaikUnitFrame.OPTION_NAME, "status_bar", GetOpt())
    RootStatusBar:AddBars(STATUSBARS, UNIT_TEXTURE_DB)
end

function StatusBar:OnEnable()
    Log:v("StatusBar_OnEnable")
    Hook:EnsureSecureHook(self, "UnitFrameManaBar_UpdateType",
                          PostHook_UnitFrameManaBar_UpdateType)
    RootStatusBar:SyncCategory(UNIT_TEXTURE_DB)
end

function StatusBar:OnDisable()
    Log:v("StatusBar_OnDisable")
    Hook:EnsureUnhook(self, "UnitFrameManaBar_UpdateType")
end
